==> cryptlex_python_sdk-1.0.2.tar.gz: cryptlex_python_sdk-1.0.2/src/cryptlex_web_api_client/api/trial_activations/postv3trial_activationsidextend.py <==
from typing import Any, Dict, Optional, Union

import httpx

from ...client import Client
from ...models.http_error_response_dto import HttpErrorResponseDto
from ...models.postv_3_trial_activationsidextend_json_body import Postv3TrialActivationsidextendJsonBody
from ...models.trial_activation_dto import TrialActivationDto
from ...types import Response


def _get_kwargs(
    id: str,
    *,
    client: Client,
    json_body: Postv3TrialActivationsidextendJsonBody,
) -> Dict[str, Any]:
    url = "{}/v3/trial-activations/{id}/extend".format(client.base_url, id=id)

    headers: Dict[str, Any] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    json_json_body = json_body.to_dict()

    return {
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "json": json_json_body,
    }


def _parse_response(*, response: httpx.Response) -> Optional[Union[HttpErrorResponseDto, TrialActivationDto]]:
    if response.status_code == 200:
        response_200 = TrialActivationDto.from_dict(response.json())

        return response_200
    if response.status_code == 401:
        response_401 = HttpErrorResponseDto.from_dict(response.json())

        return response_401
    if response.status_code == 403:
        response_403 = HttpErrorResponseDto.from_dict(response.json())

        return response_403
    if response.status_code == 404:
        response_404 = HttpErrorResponseDto.from_dict(response.json())

        return response_404
    if response.status_code == 400:
        response_400 = HttpErrorResponseDto.from_dict(response.json())

        return response_400
    if response.status_code == 409:
        response_409 = HttpErrorResponseDto.from_dict(response.json())

        return response_409
    if response.status_code == 429:
        response_429 = HttpErrorResponseDto.from_dict(response.json())

        return response_429
    if response.status_code == 500:
        response_500 = HttpErrorResponseDto.from_dict(response.json())

        return response_500
    return None


def _build_response(*, response: httpx.Response) -> Response[Union[HttpErrorResponseDto, TrialActivationDto]]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    id: str,
    *,
    client: Client,
    json_body: Postv3TrialActivationsidextendJsonBody,
) -> Response[Union[HttpErrorResponseDto, TrialActivationDto]]:
    kwargs = _get_kwargs(
        id=id,
        client=client,
        json_body=json_body,
    )

    response = httpx.post(
        verify=client.verify_ssl,
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    id: str,
    *,
    client: Client,
    json_body: Postv3TrialActivationsidextendJsonBody,
) -> Optional[Union[HttpErrorResponseDto, TrialActivationDto]]:
    """Extends the trial expiry by extension length."""

    return sync_detailed(
        id=id,
        client=client,
        json_body=json_body,
    ).parsed


async def asyncio_detailed(
    id: str,
    *,
    client: Client,
    json_body: Postv3TrialActivationsidextendJsonBody,
) -> Response[Union[HttpErrorResponseDto, TrialActivationDto]]:
    kwargs = _get_kwargs(
        id=id,
        client=client,
        json_body=json_body,
    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.post(**kwargs)

    return _build_response(response=response)


async def asyncio(
    id: str,
    *,
    client: Client,
    json_body: Postv3TrialActivationsidextendJsonBody,
) -> Optional[Union[HttpErrorResponseDto, TrialActivationDto]]:
    """Extends the trial expiry by extension length."""

    return (
        await asyncio_detailed(
            id=id,
            client=client,
            json_body=json_body,
        )
    ).parsed

==> cryptlex_python_sdk-1.0.3.tar.gz: cryptlex_python_sdk-1.0.3/src/cryptlex_web_api_client/api/trial_activations/postv3trial_activationsidextend.py <==
from typing import Any, Dict, Optional, Union

import httpx

from ...client import Client
from ...models.http_error_response_dto import HttpErrorResponseDto
from ...models.postv_3_trial_activationsidextend_json_body import Postv3TrialActivationsidextendJsonBody
from ...models.trial_activation_dto import TrialActivationDto
from ...types import Response


def _get_kwargs(
    id: str,
    *,
    client: Client,
    json_body: Postv3TrialActivationsidextendJsonBody,
) -> Dict[str, Any]:
    url = "{}/v3/trial-activations/{id}/extend".format(client.base_url, id=id)

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    json_json_body = json_body.to_dict()

    return {
        "method": "post",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "json": json_json_body,
    }


def _parse_response(*, response: httpx.Response) -> Optional[Union[HttpErrorResponseDto, TrialActivationDto]]:
    if response.status_code == 200:
        response_200 = TrialActivationDto.from_dict(response.json())

        return response_200
    if response.status_code == 400:
        response_400 = HttpErrorResponseDto.from_dict(response.json())

        return response_400
    if response.status_code == 401:
        response_401 = HttpErrorResponseDto.from_dict(response.json())

        return response_401
    if response.status_code == 403:
        response_403 = HttpErrorResponseDto.from_dict(response.json())

        return response_403
    if response.status_code == 404:
        response_404 = HttpErrorResponseDto.from_dict(response.json())

        return response_404
    if response.status_code == 409:
        response_409 = HttpErrorResponseDto.from_dict(response.json())

        return response_409
    if response.status_code == 429:
        response_429 = HttpErrorResponseDto.from_dict(response.json())

        return response_429
    if response.status_code == 500:
        response_500 = HttpErrorResponseDto.from_dict(response.json())

        return response_500
    return None


def _build_response(*, response: httpx.Response) -> Response[Union[HttpErrorResponseDto, TrialActivationDto]]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    id: str,
    *,
    client: Client,
    json_body: Postv3TrialActivationsidextendJsonBody,
) -> Response[Union[HttpErrorResponseDto, TrialActivationDto]]:
    """Extend a trial activation

     Extends the trial expiry by extension length.

    Args:
        id (str):
        json_body (Postv3TrialActivationsidextendJsonBody):

    Returns:
        Response[Union[HttpErrorResponseDto, TrialActivationDto]]
    """

    kwargs = _get_kwargs(
        id=id,
        client=client,
        json_body=json_body,
    )

    response = httpx.request(
        verify=client.verify_ssl,
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    id: str,
    *,
    client: Client,
    json_body: Postv3TrialActivationsidextendJsonBody,
) -> Optional[Union[HttpErrorResponseDto, TrialActivationDto]]:
    """Extend a trial activation

     Extends the trial expiry by extension length.

    Args:
        id (str):
        json_body (Postv3TrialActivationsidextendJsonBody):

    Returns:
        Response[Union[HttpErrorResponseDto, TrialActivationDto]]
    """

    return sync_detailed(
        id=id,
        client=client,
        json_body=json_body,
    ).parsed


async def asyncio_detailed(
    id: str,
    *,
    client: Client,
    json_body: Postv3TrialActivationsidextendJsonBody,
) -> Response[Union[HttpErrorResponseDto, TrialActivationDto]]:
    """Extend a trial activation

     Extends the trial expiry by extension length.

    Args:
        id (str):
        json_body (Postv3TrialActivationsidextendJsonBody):

    Returns:
        Response[Union[HttpErrorResponseDto, TrialActivationDto]]
    """

    kwargs = _get_kwargs(
        id=id,
        client=client,
        json_body=json_body,
    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.request(**kwargs)

    return _build_response(response=response)


async def asyncio(
    id: str,
    *,
    client: Client,
    json_body: Postv3TrialActivationsidextendJsonBody,
) -> Optional[Union[HttpErrorResponseDto, TrialActivationDto]]:
    """Extend a trial activation

     Extends the trial expiry by extension length.

    Args:
        id (str):
        json_body (Postv3TrialActivationsidextendJsonBody):

    Returns:
        Response[Union[HttpErrorResponseDto, TrialActivationDto]]
    """

    return (
        await asyncio_detailed(
            id=id,
            client=client,
            json_body=json_body,
        )
    ).parsed
